@@ -83,8 +83,13 @@ __all__ = (
     'failure_traceback',  # returns a traceback instance from an IFailedFuture
     'failure_format_traceback',  # a string, the formatted traceback
 
+    'make_batched_timer',  # create BatchedTimer/IBatchedTimer instances
+
     'make_logger',     # creates an object implementing ILogger
     'start_logging',   # initializes logging (may grab stdin at this point)
+    'set_global_log_level',  # Set the global log level
+    'get_global_log_level',  # Get the global log level
+    'add_log_categories',
 
     'IFailedFuture',             # describes API for arg to errback()s
     'ILogger',                   # API for logging
@@ -134,5 +139,5 @@ def _use_framework(module):
 # use the "un-framework", which is neither asyncio nor twisted and
 # just throws an exception -- this forces you to call .use_twisted()
 # or .use_asyncio() to use the library.
-from txaio import _unframework
+from txaio import _unframework  # noqa
 _use_framework(_unframework)
